@@ -1,4 +1,4 @@
-# $Id: krige.cv.q,v 1.16 2009-08-17 14:38:28 edzer Exp $
+# $Id: krige.cv.q,v 1.18 2009-10-30 16:11:21 edzer Exp $
 
 if (!isGeneric("krige.cv"))
 	setGeneric("krige.cv", function(formula, locations, ...)
@@ -6,7 +6,7 @@ if (!isGeneric("krige.cv"))
 
 krige.cv.locations = function (formula, locations, data = sys.frame(sys.frame(sys.parent())), 
 	model = NULL, ..., beta = NULL, nmax = Inf, nmin = 0, maxdist = Inf, 
-	nfold = nrow(data), verbose = FALSE, debug.level = 1) {
+	nfold = nrow(data), verbose = TRUE, debug.level = 0) {
 
 	gstat.cv(gstat(g = NULL, id = "var1", formula = formula, locations = 
 		locations, data = data, model = model, beta = beta, nmax = nmax, 
@@ -16,8 +16,8 @@ krige.cv.locations = function (formula, locations, data = sys.frame(sys.frame(sy
 setMethod("krige.cv", c("formula", "formula"), krige.cv.locations)
 
 krige.cv.spatial = function (formula, locations, model = NULL, ..., beta = NULL,
-	nmax = Inf, nmin = 0, maxdist = Inf, nfold = nrow(locations), verbose = FALSE,
-	debug.level = 1) {
+	nmax = Inf, nmin = 0, maxdist = Inf, nfold = nrow(locations), verbose = TRUE,
+	debug.level = 0) {
 
 	# data = locations 
 	gstat.cv(gstat(g = NULL, id = "var1", formula = formula,
